@@ -439,18 +439,17 @@ module Html2haml
 
       def attribute_value_can_be_bare_ruby?(value)
         begin
-          ruby = RubyParser.new.parse(value)
+          ruby = RubyParser.for_current_ruby.parse(value)
         rescue Racc::ParseError, RubyParser::SyntaxError
           return false
         end
 
         return false if ruby.nil?
-        return true if ruby.sexp_type == :str   #regular string
-        return true if ruby.sexp_type == :dstr  #string with interpolation
-        return true if ruby.sexp_type == :lit   #symbol
-        return true if ruby.sexp_type == :call && ruby.mass == 1 #local var or method with no params
 
-        false
+        (ruby.sexp_type == :str) ||   #regular string
+        (ruby.sexp_type == :dstr) ||  #string with interpolation
+        (ruby.sexp_type == :lit) ||   #symbol
+        (ruby.sexp_type == :call && ruby.mass == 1) #local var or method with no params
       end
 
 
